yakumo.nova.v2.service

Package yakumo :: Package nova :: Package v2 :: Module service |
[hide private]
[frames] | no frames]

# Module service

source code

Resource class and its manager for services in Compute API v2

Classes | [hide private]
| Resource Resource class for services in Compute API v2
| Manager Manager class for services in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('host', 'host', mapper.Noop), ('binary',
      'binary', mapper.Noop), ('state', 'state', mapper.Noop), ('status', 's
      tatus', mapper.Noop), ('updated_at', 'updated_at', mapper.DateTime), (
      'availability_zone', 'zone', mapper.Resource('nova.availability_zone')
      ), ('disabled_reason', 'disabled_reason', mapper.Noop),]